/*
  *
 * Copyright (C) 2018 Texas Instruments Incorporated - http://www.ti.com/
 *
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
*/


/**********************************************************

2/14/2018 Version 0.0, confirm the single tell-tale diagnostic configuration
                       configurate 0 to the reltaive bit.
2/16/2018 Version 0.1, confirm the audio function

2/28/2018 Version 0.2, all function good, except the tell-tale feedback

3/2/2018 Version 1.0, all function good
**********************************************************/


/**********Backlight/ Sensor/ Audio Pin configuration*********

        Pin 1.5 as Backlight PWM control
        Pin 4.0 as Backlight ERR feedback

        Pin 7.0 as Shutdown
        Pin 2.0 as Audio PWM input

        Pin 6.0 as Sensor ADC output to MCU

        Pin 8.2 as Short Report
        Pin 4.1 as Open Report

************************************************************/

/*************TLC6C5816 Pin configuration*******************

        Pin 3.2 as Enable
        Pin 1.4 as Clear
        Pin 3.7 as Error
        Pin 2.5 as G1 gate control
        Pin 2.4 as G2 gate control
        Pin 1.3 as RCK -- latch signal

        Pin 2.7 as SRCK -- clock, resister clock
        Pin 3.3 as SIMO -- SER IN
        Pin 3.4 as SOMI -- SER OUT

***********************************************************/

/*************Simulation Pin configuration*****************

        Pin 6.1 as Beam light open/ close
        Pin 6.2 as Turn Left open/ close
        Pin 6.3 as Safety Belt Warning
        Pin 6.4 as Reverse shift

***********************************************************/

#include "driverlib.h"

#define RCK_UP    (P1OUT |= BIT3)
#define RCK_DOWN  (P1OUT &= ~BIT3)
#define Open_ON (P8OUT |= BIT2)
#define Open_OFF (P8OUT &= ~BIT2)
#define Short_ON (P4OUT |= BIT1)
#define Short_OFF (P4OUT &= ~BIT1)
#define MuteOff (P7OUT |= BIT0)
#define MuteOn (P7OUT &= ~BIT0)


const float DayBright = 1000;//3.3/4096*3000=2.4v
const long def_State[3] = {0,0x20A006,0xEA0004};//default state for tell-tale{device 3,device 2,device 1}
const long all_State[3] = {0x00FFFF,0x20F7FF,0xEA5777};//all light for tell-tale{device 3,device 2,device 1}{0x00FFFF,0x20A7F6,0xEA5777}
const long rev_State[3] = {0,0x20A009,0xEA0004};// reverse state for tell-tale{device 3,device 2,device 1}
float Brightness = 0;
unsigned int def_Bright = 15;
unsigned int set_Bright = 7;
unsigned int fre1 = 5000;//6000  20,000--1kHz, 40,000--500Hz
unsigned int duty1 = 200;
short test = 0;
int state = 0;
int last_State = 0;
int temp_state = 0;
typedef struct{
    uint32_t Data[3];
}RX_DATA;

RX_DATA rxData;

void setGPIO(void){
    //LED
    GPIO_setAsOutputPin(GPIO_PORT_P1,GPIO_PIN0);
    GPIO_setAsOutputPin(GPIO_PORT_P4,GPIO_PIN7);
    GPIO_setOutputLowOnPin(GPIO_PORT_P4,GPIO_PIN7);

    //Latch--RCK
    GPIO_setAsOutputPin(GPIO_PORT_P1,GPIO_PIN3);
    //ENABLE
    GPIO_setAsOutputPin(GPIO_PORT_P3,GPIO_PIN2);
    GPIO_setOutputLowOnPin(GPIO_PORT_P3,GPIO_PIN2);
    //CLEAR
    GPIO_setAsOutputPin(GPIO_PORT_P1,GPIO_PIN4);
    GPIO_setOutputHighOnPin(GPIO_PORT_P1,GPIO_PIN4);

    //ERR
    GPIO_setAsInputPin(GPIO_PORT_P3, GPIO_PIN7);
    GPIO_setAsInputPinWithPullUpResistor(GPIO_PORT_P3, GPIO_PIN7);

    //Function Simulation Pin 6.1 as Beam light open/ close & Pin 6.2 as Turn Left open/ close & Pin 6.3 as Safety Belt Warning & Pin 6.4 as Reverse shift
    GPIO_setAsInputPin(GPIO_PORT_P6, GPIO_PIN1 + GPIO_PIN2 + GPIO_PIN3 + GPIO_PIN4);
    GPIO_setAsInputPinWithPullDownResistor(GPIO_PORT_P6, GPIO_PIN1 + GPIO_PIN2 + GPIO_PIN3 + GPIO_PIN4);

    // Audio Shutdown P7.0
    GPIO_setAsOutputPin(GPIO_PORT_P7,GPIO_PIN0);
    GPIO_setOutputLowOnPin(GPIO_PORT_P7,GPIO_PIN0);

    // Short Fault Report P4.1
    GPIO_setAsOutputPin(GPIO_PORT_P4,GPIO_PIN1);
    GPIO_setOutputLowOnPin(GPIO_PORT_P4,GPIO_PIN1);
    // Open Fault Report P8.2
    GPIO_setAsOutputPin(GPIO_PORT_P8,GPIO_PIN2);
    GPIO_setOutputLowOnPin(GPIO_PORT_P8,GPIO_PIN2);

    //Botton1
    //button1,P2.1
    GPIO_setAsInputPin(GPIO_PORT_P2, GPIO_PIN1);
    GPIO_setAsInputPinWithPullUpResistor(GPIO_PORT_P2, GPIO_PIN1);
    GPIO_setAsInputPin(GPIO_PORT_P1, GPIO_PIN1);
    GPIO_setAsInputPinWithPullUpResistor(GPIO_PORT_P1, GPIO_PIN1);
}
short getTelltale(void){
    short m = 0;
    m |= GPIO_getInputPinValue(GPIO_PORT_P6, GPIO_PIN1);// Beam
    m |= GPIO_getInputPinValue(GPIO_PORT_P6, GPIO_PIN2) << 1;// Left
    m |= GPIO_getInputPinValue(GPIO_PORT_P6, GPIO_PIN3) << 2;// Belt
    m |= GPIO_getInputPinValue(GPIO_PORT_P6, GPIO_PIN4) << 3;// Reverse
    return(m);
}
void setADC(void){
    //P6.0 ADC option select
    GPIO_setAsPeripheralModuleFunctionOutputPin(GPIO_PORT_P6, GPIO_PIN0);

    ADC12_A_init(ADC12_A_BASE, ADC12_A_SAMPLEHOLDSOURCE_SC, ADC12_A_CLOCKSOURCE_MCLK, ADC12_A_CLOCKDIVIDER_4);

    ADC12_A_enable(ADC12_A_BASE);

    ADC12_A_setupSamplingTimer(ADC12_A_BASE, ADC12_A_CYCLEHOLD_4_CYCLES, ADC12_A_CYCLEHOLD_4_CYCLES, ADC12_A_MULTIPLESAMPLESDISABLE);

    ADC12_A_configureMemoryParam param = {0};
    param.memoryBufferControlIndex = ADC12_A_MEMORY_0;
    param.inputSourceSelect = ADC12_A_INPUT_A0;
    param.positiveRefVoltageSourceSelect = ADC12_A_VREFPOS_AVCC;
    param.negativeRefVoltageSourceSelect = ADC12_A_VREFNEG_AVSS;
    param.endOfSequence = ADC12_A_NOTENDOFSEQUENCE;
    ADC12_A_configureMemory(ADC12_A_BASE,&param);

    //Enable memory buffer 0 interrupt
//    ADC12_A_clearInterrupt(ADC12_A_BASE, ADC12IFG0);
//    ADC12_A_enableInterrupt(ADC12_A_BASE, ADC12IE0);
}
//G1---P2.5, TA2.2(same Timer A with G2, only use different duty cycle)
void setG1PWM(unsigned int TIMER_PERIOD,unsigned int DUTY_CYCLE){
    //G1
    GPIO_setAsPeripheralModuleFunctionOutputPin(GPIO_PORT_P2, GPIO_PIN5);

    //Generate PWM - Timer runs in Up mode
    Timer_A_outputPWMParam param = {0};
    param.clockSource = TIMER_A_CLOCKSOURCE_SMCLK;
    param.clockSourceDivider = TIMER_A_CLOCKSOURCE_DIVIDER_1;
    param.timerPeriod = TIMER_PERIOD;
    param.compareRegister = TIMER_A_CAPTURECOMPARE_REGISTER_2;
    param.compareOutputMode = TIMER_A_OUTPUTMODE_RESET_SET;
    param.dutyCycle = DUTY_CYCLE;
    Timer_A_outputPWM(TIMER_A2_BASE, &param);
}
//G2---P2.4, TA2.1
void setG2PWM(unsigned int TIMER_PERIOD,unsigned int DUTY_CYCLE){
    //G1
    GPIO_setAsPeripheralModuleFunctionOutputPin(GPIO_PORT_P2, GPIO_PIN4);

    //Generate PWM - Timer runs in Up mode
    Timer_A_outputPWMParam param = {0};
    param.clockSource = TIMER_A_CLOCKSOURCE_SMCLK;
    param.clockSourceDivider = TIMER_A_CLOCKSOURCE_DIVIDER_1;
    param.timerPeriod = TIMER_PERIOD;
    param.compareRegister = TIMER_A_CAPTURECOMPARE_REGISTER_1;
    param.compareOutputMode = TIMER_A_OUTPUTMODE_RESET_SET;
    param.dutyCycle = DUTY_CYCLE;
    Timer_A_outputPWM(TIMER_A2_BASE, &param);
}
//Backlight PWM---P1.5, TA0.4
void setBLPWM(unsigned int TIMER_PERIOD,unsigned int DUTY_CYCLE){
    //G2
    GPIO_setAsPeripheralModuleFunctionOutputPin(GPIO_PORT_P1, GPIO_PIN5);

    //Generate PWM - Timer runs in Up mode
    Timer_A_outputPWMParam param = {0};
    param.clockSource = TIMER_A_CLOCKSOURCE_SMCLK;
    param.clockSourceDivider = TIMER_A_CLOCKSOURCE_DIVIDER_1;
    param.timerPeriod = TIMER_PERIOD;
    param.compareRegister = TIMER_A_CAPTURECOMPARE_REGISTER_4;
    param.compareOutputMode = TIMER_A_OUTPUTMODE_RESET_SET;
    param.dutyCycle = DUTY_CYCLE;
    Timer_A_outputPWM(TIMER_A0_BASE, &param);
}
//Audio PWM --- P2.0, TA1.1
void setAudPWM(unsigned int TIMER_PERIOD,unsigned int DUTY_CYCLE){
    GPIO_setAsPeripheralModuleFunctionOutputPin(GPIO_PORT_P2, GPIO_PIN0);

    //Generate PWM - Timer runs in Up mode
    Timer_A_outputPWMParam param = {0};
    param.clockSource = TIMER_A_CLOCKSOURCE_SMCLK;
    param.clockSourceDivider = TIMER_A_CLOCKSOURCE_DIVIDER_1;
    param.timerPeriod = TIMER_PERIOD;
    param.compareRegister = TIMER_A_CAPTURECOMPARE_REGISTER_1;
    param.compareOutputMode = TIMER_A_OUTPUTMODE_RESET_SET;
    param.dutyCycle = DUTY_CYCLE;
    Timer_A_outputPWM(TIMER_A1_BASE, &param);
}

void setSPI(void){
    P3SEL |= BIT3+BIT4;                       // P3.3,4 option select 3.3SIMO 3.4SOMI
    P2SEL |= BIT7;                            // P2.7 option select 2.7CLK

    UCA0CTL1 |= UCSWRST;                      // **Put state machine in reset**
    UCA0CTL0 |= UCMST+UCSYNC+UCMSB+UCCKPH;//+UCMSB;    // 3-pin, 8-bit SPI master
                                                // Clock polarity high,+UCCKPL MSB
    UCA0CTL1 |= UCSSEL_2;                     // SMCLK
    UCA0BR0 = 4;                           // /2
    UCA0BR1 = 0;                              //
    UCA0MCTL = 0;                             // No modulation
    UCA0CTL1 &= ~UCSWRST;                     // **Initialize USCI state machine**
}
void spiWrite(long data1,long data2,long data3)
{
    __delay_cycles(20);
    RCK_DOWN;

    // Transmit first 24bit data MSB
    while (!(UCA0IFG&UCTXIFG));  // USCI_A0 TX buffer ready?
        UCA0TXBUF = (data1>>16);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = (data1>>8);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = (data1);
    while (!(UCA0IFG&UCTXIFG));

    // Transmit second 24bit data
        UCA0TXBUF = (data2>>16);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = (data2>>8);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = (data2);
    while (!(UCA0IFG&UCTXIFG));

    // Transmit third 24bit data

        UCA0TXBUF = (data3>>16);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = (data3>>8);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = (data3);
    while (!(UCA0IFG&UCTXIFG));

    __delay_cycles(20);
        RCK_UP;
    __delay_cycles(20);
        RCK_DOWN;
}
void spiWrite1(long data1)
{
    __delay_cycles(20);
    RCK_DOWN;

    // Transmit first 24bit data MSB
    while (!(UCA0IFG&UCTXIFG));  // USCI_A0 TX buffer ready?
        UCA0TXBUF = (data1>>16);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = (data1>>8);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = (data1);
    while (!(UCA0IFG&UCTXIFG));

    __delay_cycles(20);
    RCK_UP;

}

void readData1(RX_DATA *RxData)
{
    uint8_t temp = 0;
    RxData->Data[0]=0;
    RxData->Data[1]=0;
    RxData->Data[2]=0;
    RCK_UP;
    __delay_cycles(10);
    // read first 24bit data
    while (!(UCA0IFG&UCTXIFG));

        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
        temp = UCA0RXBUF;
        RxData->Data[2] = (((uint32_t)temp)<<16);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
        temp = UCA0RXBUF;
        RxData->Data[2] |= (((uint32_t)temp)<<8);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
        temp = UCA0RXBUF;
        RxData->Data[2] |= (((uint32_t)temp));

    // read second 24bit data
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
        temp = UCA0RXBUF;
        RxData->Data[1] = (((uint32_t)temp)<<16);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
        temp = UCA0RXBUF;
        RxData->Data[1] |= (((uint32_t)temp)<<8);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
        temp = UCA0RXBUF;
        RxData->Data[1] |= (((uint32_t)temp));

    // read third 24bit data
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
        temp = UCA0RXBUF;
        RxData->Data[0] = (((uint32_t)temp)<<16);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
        temp = UCA0RXBUF;
        RxData->Data[0] |= (((uint32_t)temp)<<8);
    while (!(UCA0IFG&UCTXIFG));
        UCA0TXBUF = 0x00;
    while (!(UCA0IFG&UCRXIFG));
        temp = UCA0RXBUF;
        RxData->Data[0] |= (((uint32_t)temp));
    __delay_cycles(20);
    RCK_DOWN;

}
float getBrightness1(void){

    int a = 0;
    ADC12_A_startConversion(ADC12_A_BASE, ADC12_A_MEMORY_0, ADC12_A_SINGLECHANNEL);
    a = ADC12_A_getResults(ADC12_A_BASE,ADC12_A_MEMORY_0);// <= 0xE8B9)//E8B9--3V
    Brightness = a;


    return(Brightness);//4096

}
float getBrightness(void){

    int a = 0;
    ADC12_A_startConversion(ADC12_A_BASE, ADC12_A_MEMORY_0, ADC12_A_SINGLECHANNEL);
    a = ADC12_A_getResults(ADC12_A_BASE,ADC12_A_MEMORY_0);// <= 0xE8B9)//E8B9--3V
    Brightness = (float)(a>>12)*3.3;
    Brightness = 1 + (Brightness - 0.3)*10000/(3-0.3);

    return(Brightness);//Lux

}

void audioWarning(void){
    MuteOff;
    //duty1 = fre1>>1;
    setAudPWM(fre1,duty1);
}
void audioMute(void){
    MuteOn;
    setAudPWM(fre1,0);
}
void sysInit(void){
    GPIO_setAsPeripheralModuleFunctionOutputPin(GPIO_PORT_P7 , GPIO_PIN7);
    P5SEL |= BIT2+BIT3;                       // Port select XT2

    UCSCTL6 &= ~XT2OFF;                       // Enable XT2
    UCSCTL3 |= SELREF_5;                      // FLLref = REFO
                                              // Since LFXT1 is not used,
                                              // sourcing FLL with LFXT1 can cause
                                              // XT1OFFG flag to set
    UCSCTL4 |= SELA_2;                        // ACLK=REFO,SMCLK=DCO,MCLK=DCO
    __bis_SR_register(SCG0);                  // Disable the FLL control loop
    UCSCTL0 = 0x0000;                         // Set lowest possible DCOx, MODx
    UCSCTL1 = DCORSEL_6;                      // Select DCO range 36MHz operation
    UCSCTL2 = FLLD_1 + 4;                   // Set DCO Multiplier for 20MHz
                                            // (N + 1) * FLLRef = Fdco
                                                       // (4 + 1) * 4M = 20MHz
     __bic_SR_register(SCG0);                  // Enable the FLL control loop
     do
        {
           UCSCTL7 &= ~(XT2OFFG + XT1LFOFFG + DCOFFG);
                                                     // Clear XT2,XT1,DCO fault flags
           SFRIFG1 &= ~OFIFG;                      // Clear fault flags
           }while (SFRIFG1&OFIFG);                   // Test oscillator fault flag

     UCSCTL6 &= ~XT2DRIVE0;                    // Decrease XT2 Drive according to
                                                     // expected frequency
     UCSCTL4 |= SELS_4 + SELM_4;               // SMCLK=MCLK=20M
}


void main(void)
{
    unsigned int i,j,m,n,State_BL=0;
    //Stop Watchdog Timer
    WDT_A_hold(WDT_A_BASE);
    sysInit();
    setADC();
    setGPIO();
    setSPI();
    setG1PWM(2000,500);//20khz
    setG2PWM(2000,500);//20khz
    setBLPWM(4000,def_Bright);
    setAudPWM(fre1,duty1);
    // waiting for all control default, must set all switches default - leave this out to have unit come up regardless of switch position.
//    while(GPIO_getInputPinValue(GPIO_PORT_P6, GPIO_PIN1) || GPIO_getInputPinValue(GPIO_PORT_P6, GPIO_PIN2) || GPIO_getInputPinValue(GPIO_PORT_P6, GPIO_PIN3) || GPIO_getInputPinValue(GPIO_PORT_P6, GPIO_PIN4));
    //all ON/OFF const long def_State[3] = {0,0x208086,0xEA0000};
    spiWrite(all_State[0], all_State[1], all_State[2]); //all telltale on
    Short_ON;
    Open_ON;
    for(m=0;m<50;m++){
       for(i=0;i<5000;i++){
          __delay_cycles(100);
       }
    }
    spiWrite(def_State[0], def_State[1], def_State[2]);// all telltale default
    Short_OFF;
    Open_OFF;
    __delay_cycles(1000);
    __delay_cycles(1000);
    __delay_cycles(1000);

    //default configuration 23-0
    //Device 1: 1110,1010,0000,0000,0000,0000   1110,1010,0101,0111,0111,0111
    //Device 2: 0010,0000,1010,0000,0000,0110
    //Device 3: 0000,0000,0000,0000,0000,0000

    while(1)
    {
        switch(state){
            case 0:{
                // Detect the tell-tale err
                short error = GPIO_getInputPinValue(GPIO_PORT_P3, GPIO_PIN7);
                if(error == 0){
                    readData1(&rxData);
                    if (((rxData.Data[0]) & 0xffffff)!=0){//readback resister detected
                        state = 0;
                        if ((((rxData.Data[0]) >>10) & 0x01) == 1){//bit10 open diagnostic
                            Open_ON;
                            
                        }
                        else if ((((rxData.Data[0]) >>11) & 0x01) == 1){//bit11 short diagnostic
                            Short_ON;
                            
                        }
                        else{
                            Short_OFF;
                            Open_OFF;
                        }

                    }
                    else{
                         Short_OFF;
                         Open_OFF;
                    }
                }
                else{
                    Short_OFF;
                    Open_OFF;
                    if((last_State==0) && (State_BL == 2000)){
                       state = 1;
                       State_BL = 0;
                    }
                    else if((last_State==1)){
                       state = 1;
                       State_BL = 0;
                    }
                    else{
                       State_BL++;
                       state = 3;
                    }
                }

                break;

            }
            case 1:{
                // define the cluster mode for brightness
                float a = getBrightness1();
                if (a <= DayBright){// Goto night mode
                    set_Bright = (def_Bright - 1 + a/100);
//                    state = 2;
                }
                else {// Goto tell-tale control mode
                    set_Bright = (def_Bright + 10 + a/100);
//                    setBLPWM(4000, 4);
//                    state =3;
                }
                state = 2;
                break;
            }
            case 2:{
                //could control brightness based on the sensor value
                setBLPWM(4000,set_Bright);
                state = 3;
                break;
            }
            case 3:{
                //detect the tell-tale control
                //Function Simulation Pin 6.1 as Beam light open/ close & Pin 6.2 as Turn Left open/ close & Pin 6.3 as Safety Belt Warning & Pin 6.4 as Reverse shift
                // Reverse Belt Left Beam

                temp_state = getTelltale();
                if (((temp_state) & 0x06) == 0 ){//NO flash and audio requirement
                    state = 4;
                    last_State=0;
                }
                else{// trig left or belt
                    state = 5;
                    last_State=1;
                }
                break;
            }
            case 4:{//only the beam and reverse control
                if ((temp_state & 0x08) == 8){// reverse control trig
                    spiWrite(rev_State[0],(rev_State[1]|((temp_state & 0x01)<<5)),rev_State[2]);
                }
                else{
                    spiWrite(def_State[0],(def_State[1]|((temp_state & 0x01)<<5)),def_State[2]);
                }
                state = 0;
                break;
            }
            case 5:{

                if ((temp_state & 0x08) == 8){// reverse control trig
                    spiWrite((rev_State[0]|(((temp_state & 0x02)>>1)<<8)),(rev_State[1]|((temp_state & 0x01)<<5)),(rev_State[2]|(((temp_state & 0x04)>>2)<<6)));
                    audioWarning();
                    for(m=0;m<5;m++){
                       for(i=0;i<5000;i++){
                          __delay_cycles(100);
                       }
                    }
                    audioMute();
                    for(m=0;m<10;m++){
                        for(i=0;i<5000;i++){
                            __delay_cycles(100);
                        }
                    }
                    spiWrite((rev_State[0]),(rev_State[1]|((temp_state & 0x01)<<5)),(rev_State[2]|(((temp_state & 0x04)>>2)<<6)));

                    for(m=0;m<15;m++){
                        for(i=0;i<5000;i++){
                            __delay_cycles(100);
                        }
                    }
                }
                else{
                    spiWrite((def_State[0]|(((temp_state & 0x02)>>1)<<8)),(def_State[1]|((temp_state & 0x01)<<5)),(def_State[2]|(((temp_state & 0x04)>>2)<<6)));
                    audioWarning();
                    for(m=0;m<5;m++){
                       for(i=0;i<5000;i++){
                           __delay_cycles(100);
                       }
                    }
                    audioMute();
                    for(m=0;m<10;m++){
                       for(i=0;i<5000;i++){
                          __delay_cycles(100);
                       }
                    }
                    spiWrite((def_State[0]),(def_State[1]|((temp_state & 0x01)<<5)),(def_State[2]|(((temp_state & 0x04)>>2)<<6)));
                    for(m=0;m<15;m++){
                        for(i=0;i<5000;i++){
                            __delay_cycles(100);
                        }
                    }
                }
                state = 0;
                break;
            }
            }
        }
// */
}

